You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ma...@apache.org on 2013/08/19 20:12:58 UTC

svn commit: r1515541 - /openoffice/ooo-site/trunk/content/download/download.js

Author: marcus
Date: Mon Aug 19 18:12:58 2013
New Revision: 1515541

URL: http://svn.apache.org/r1515541
Log:
Fixed JS error when a language is not supported for an AOO release but a download link is assembled anyway

Modified:
    openoffice/ooo-site/trunk/content/download/download.js

Modified: openoffice/ooo-site/trunk/content/download/download.js
URL: http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/download/download.js?rev=1515541&r1=1515540&r2=1515541&view=diff
==============================================================================
--- openoffice/ooo-site/trunk/content/download/download.js (original)
+++ openoffice/ooo-site/trunk/content/download/download.js Mon Aug 19 18:12:58 2013
@@ -133,6 +133,7 @@ function getLink() {
 	var chk_link = "";
 
 	getLanguage();
+	hasMirrorLink();
 	getPlatform();
 	getFilesize();
 
@@ -339,8 +340,8 @@ function getFilesize() {
 			RELEASE_MATRIX_PLATFORM_POS = -1;
 	}
 
-	// If a platform was found, assign the array data and filesize from the release matrix
-	if ( RELEASE_MATRIX_PLATFORM_POS > -1 ) {
+	// If a platform was found and no error occurred, assign the array data and filesize from the release matrix
+	if ( RELEASE_MATRIX_PLATFORM_POS > -1 && !ERROR ) {
 		// Assign all values from the release matrix of language and platform
 		RELEASE_MATRIX_PLATFORM		= release_aoo400_matrix[ LANG_ISO ][ RELEASE_MATRIX_PLATFORM_POS ];